searchData={"items":[{"type":"module","title":"Exflect","doc":"","ref":"Exflect.html"},{"type":"function","title":"Exflect.inflect/3","doc":"Inflects the input word based on the the integer given.\n\n```elixir\niex> Exflect.inflect(\"leaf\", 0)\n\"leaves\"\niex> Exflect.inflect(\"leaf\", 1)\n\"leaf\"\niex> Exflect.inflect(\"leaf\", 2)\n\"leaves\"\n```\nAlso accepts the `match_style` option","ref":"Exflect.html#inflect/3"},{"type":"function","title":"Exflect.plural?/1","doc":"Returns true is the word is plural, else false.","ref":"Exflect.html#plural?/1"},{"type":"function","title":"Exflect.pluralize/2","doc":"Pluralizes an English word.\n\n```elixir\niex> Exflect.pluralize(\"leaf\")\n\"leaves\"\n```\n\nTakes two options:\n`check`: `boolean` | default: `false`\n`match_style`: `boolean` | default: `false`\n\nUse the option `check`, if you're not sure about the form of the word you're passing in.\nFor performance reasons, to avoid a bunch of expensive regex call, by default the input is not checked to see if it's already plural.\nThis incurs about a 30x performance hit. ~40k ips vs ~1.2m ips unchecked.\n```\niex> Exflect.pluralize(\"men\")\n\"mens\"\niex> Exflect.pluralize(\"men\", check: true)\n\"men\"\n```\n\nUse the option `match_style` if you want it to maintain the current whitespace/case.\n```elixir\niex> Exflect.pluralize(\"  LEAF  \", match_style: true)\n\"  LEAVES  \"\n```","ref":"Exflect.html#pluralize/2"},{"type":"function","title":"Exflect.singular?/1","doc":"Returns true is the word is singular, else false.","ref":"Exflect.html#singular?/1"},{"type":"function","title":"Exflect.singularize/2","doc":"Singlarizes an English word.\n\n```elixir\niex> Exflect.singularize(\"leaves\")\n\"leaf\"\n```\n\nTakes two options:\n`check`: `boolean` | default: `false`\n`match_style`: `boolean` | default: `false`\n\nUse the option `check`, if you're not sure about the form of the word you're passing in.\nFor performance reasons, to avoid a bunch of expensive regex call, by default the input is not checked to see if it's already singular.\nThis incurs about a 30x performance hit. ~40k ips vs ~1.2m ips unchecked.\n```\niex> Exflect.singularize(\"bus\")\n\"bu\"\niex> Exflect.singularize(\"bus\", check: true)\n\"bus\"\n```\n\nUse the option `match_style` if you want it to maintain the current whitespace/case.\n```elixir\niex> Exflect.singularize(\"  LEAVES  \", match_style: true)\n\"  LEAF  \"\n```","ref":"Exflect.html#singularize/2"},{"type":"extras","title":"Exflect","doc":"# Exflect\n\nExflect is an Elixir inflection library for pluralization/singularization of English words.","ref":"readme.html"},{"type":"extras","title":"Installation - Exflect","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `exflect` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:exflect, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be found on [HexDocs](https://hexdocs.pm/exflect).","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Exflect","doc":"```elixir\niex> Exflect.pluralize(\"leaf\")\n\"leaves\"\niex> Exflect.singularize(\"leaves\")\n\"leaf\"\n\niex> Exflect.inflect(\"leaf\", 0)\n\"leaves\"\niex> Exflect.inflect(\"leaf\", 1)\n\"leaf\"\niex> Exflect.inflect(\"leaf\", 2)\n\"leaves\"\n\niex> Exflect.pluralize(\"  LEAF   \", match_style: true)\n\"  LEAVES   \"\niex> Exflect.pluralize(\"  Leaf   \", match_style: true)\n\"  Leaves   \"\nExflect.singularize(\"  LEAVES   \", match_style: iex> true)\n\"  LEAF   \"\niex> Exflect.inflect(\"  LEAF  \", 2, match_style: true)\n\"  LEAVES  \"\n```","ref":"readme.html#usage"},{"type":"extras","title":"FAQ - Exflect","doc":"#","ref":"readme.html#faq"},{"type":"extras","title":"Why build a new library? - Exflect","doc":"The existing one seems to not longer be maintained, and it's quite inaccurate, and not very performant(mostly because of the heavy reliance on Regex).\n\nHere are some accuracy comparisons based on the test suite compiled from other OSS inflection libraries. I've purposely removed any test data that follows the default \"add 's'\"/\"remove 's'\" rule, as it has the least value when comparing accuracy. There are about 1500 words being tested. The performance results below are also based on the same test set.\n\n\n\n|exflect|93.5%|\n|-|-|\n|inflex|76.0%|\n\n\nIt would be possible to get Exflect higher scorewise, but that 10% is a lot of edge cases, or places where varying libraries disagree. Words like \"elk\" vs \"elks\", \"buffalo\" vs \"buffaloes\" vs \"buffalos\". Also Exflect doesn't currently handle phrases like \"lady in waiting\" correctly. You'll get \"lady in waitings\" rather than \"ladies in waiting\".\n\nHere are some performance benchmarks:\n\n```\nOperating System: macOS\nCPU Information: Apple M1 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.15.3\nErlang 26.0\nJIT enabled: true\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 5 s\nmemory time: 1 s\nreduction time: 1 s\nparallel: 1\ninputs: none specified\nEstimated total run time: 36 s\n\nBenchmarking exflect ...\nBenchmarking inflex ...\nBenchmarking exflect_check ...\nBenchmarking exflect_match_style ...\nCalculating statistics...\nFormatting results...\n\nName                          ips        average  deviation         median         99th %\nexflect                    907.90        1.10 ms     ±3.40%        1.09 ms        1.24 ms\nexflect_match_style        305.59        3.27 ms     ±2.10%        3.26 ms        3.47 ms\nexflect_check               27.16       36.82 ms     ±0.76%       36.76 ms       37.46 ms\ninflex                      19.08       52.42 ms     ±0.35%       52.42 ms       52.76 ms\n\nComparison:\nexflect                    907.90\nexflect_match_style        305.59 - 2.97x slower +2.17 ms\nexflect_check               27.16 - 33.42x slower +35.71 ms\ninflex                      19.08 - 47.59x slower +51.32 ms\n\nMemory usage statistics:\n\nName                        average  deviation         median         99th %\nexflect                     2.20 MB     ±0.00%        2.20 MB        2.20 MB\nexflect_match_style         6.04 MB     ±0.00%        6.04 MB        6.04 MB\nexflect_check               6.41 MB     ±0.00%        6.41 MB        6.41 MB\ninflex                      7.93 MB     ±0.00%        7.93 MB        7.93 MB\n\nComparison:\nexflect                     2.20 MB\nexflect_match_style         6.04 MB - 2.75x memory usage +3.84 MB\nexflect_check               6.41 MB - 2.92x memory usage +4.21 MB\ninflex                      7.93 MB - 3.61x memory usage +5.74 MB\n\nReduction count statistics:\n\nName                Reduction count\nexflect                     0.104 M\nexflect_match_style          0.36 M - 3.40x reduction count +0.25 M\nexflect_check                1.05 M - 10.09x reduction count +0.95 M\ninflex                       1.40 M - 13.40x reduction count +1.30 M\n\n**All measurements for reduction count were the same**\n```\n\nYou can run these benchmarks yourself by running the test suite with the `benchmark` tag:\n\n```\nmix test --include benchmark\n```\n\n#","ref":"readme.html#why-build-a-new-library"},{"type":"extras","title":"Is it ready for production use? - Exflect","doc":"It's still a work in progress, as there are some edge cases that aren't being covered, and some code clean up I'd like to do, but I don't imagine the API will change significantly as it's fairly straightforward.","ref":"readme.html#is-it-ready-for-production-use"},{"type":"extras","title":"Credits - Exflect","doc":"The existing Elixir library [Inflex](https://github.com/nurugger07/inflex) and the Python library [Inflect](https://github.com/jaraco/inflect) were both crucial in the devlopment of this code, so thanks to them for their work.","ref":"readme.html#credits"},{"type":"extras","title":"License - Exflect","doc":"MIT License\n\nCopyright (c) 2023 Peter Richards\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"readme.html#license"}],"content_type":"text/markdown"}